@@ -1,3 +1,4 @@
+//! Rust library to flatten a JSON object using JSON Pointer field addressing as defined in [IETF RFC 6901](https://datatracker.ietf.org/doc/html/rfc6901).
 use serde::Serialize;
 use serde_json::{json, Map, Result, Value};
 
@@ -170,7 +171,7 @@ mod test {
     }
 
     #[test]
-    fn example_readme() {
+    fn test_readme_example() {
         let value = json!(
             {
                 "name": "John Smith",
@@ -188,6 +189,21 @@ mod test {
         assert!(result.is_object());
     }
 
+    #[test]
+    fn test_null() {
+        let value = json!({ "name": null });
+
+        let result = from_value(&value).unwrap();
+
+        assert!(result.is_object());
+        assert!(result
+            .as_object()
+            .unwrap()
+            .get("/name")
+            .unwrap()
+            .eq(&json!(Value::Null)));
+    }
+
     #[test]
     fn flatten_array() {
         let value = json!(
